===============================================
Welcome to the "Cloud" Sphinx Theme v |release|
===============================================

This is a small package containing a Sphinx theme named "cloud",
along with some related Sphinx extensions.
See next page for :doc:`installation instructions <install>`.

Themes
------
* :doc:`Cloud <cloud_theme>` - a Sphinx theme, used by this documentation

Sphinx Extensions
-----------------
* :mod:`cloud_sptheme.ext.autodoc_sections` - allows autodoc to handle RST section headers inside class/method docstrings
* :mod:`cloud_sptheme.ext.index_styling` - adds css styling to the general index
* :mod:`cloud_sptheme.ext.relbar_toc` - adds a TOC link to the right in the relbar

Utilities
---------
* :mod:`cloud_sptheme.make_helper` - a sphinx-build Makefile replacement

Online Resources
================
* **Homepage & Source:** `<https://bitbucket.org/ecollins/cloud_sptheme>`_
* **Docs:** `<http://packages.python.org/cloud_sptheme>`_
* **Download & PyPI:** `<http://pypi.python.org/pypi/cloud_sptheme>`_
